# Schemas

=== "JSON Schema"

    ```json
    {!> schemas/epdx.schema.json!}
    ```

=== "Python"

    ```python
    {!> schemas/pydantic.py!}
    ```

=== "TypeScript"

    ```typescript
    {!> schemas/epdx.d.ts!}
    ```